==> aliyun-python-sdk-vcs-1.1.1.tar.gz: aliyun-python-sdk-vcs-1.1.1/aliyunsdkvcs/request/v20200515/RegisterDeviceRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkvcs.endpoint import endpoint_data

class RegisterDeviceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Vcs', '2020-05-15', 'RegisterDevice','vcs')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_DeviceTimeStamp(self):
		return self.get_body_params().get('DeviceTimeStamp')

	def set_DeviceTimeStamp(self,DeviceTimeStamp):
		self.add_body_params('DeviceTimeStamp', DeviceTimeStamp)

	def get_DeviceId(self):
		return self.get_body_params().get('DeviceId')

	def set_DeviceId(self,DeviceId):
		self.add_body_params('DeviceId', DeviceId)

	def get_ServerId(self):
		return self.get_body_params().get('ServerId')

	def set_ServerId(self,ServerId):
		self.add_body_params('ServerId', ServerId)

	def get_DeviceSerialNumber(self):
		return self.get_body_params().get('DeviceSerialNumber')

	def set_DeviceSerialNumber(self,DeviceSerialNumber):
		self.add_body_params('DeviceSerialNumber', DeviceSerialNumber)

==> aliyun-python-sdk-vcs-1.2.5.tar.gz: aliyun-python-sdk-vcs-1.2.5/aliyunsdkvcs/request/v20200515/RegisterDeviceRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkvcs.endpoint import endpoint_data

class RegisterDeviceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Vcs', '2020-05-15', 'RegisterDevice','vcs')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_DeviceTimeStamp(self):
		return self.get_body_params().get('DeviceTimeStamp')

	def set_DeviceTimeStamp(self,DeviceTimeStamp):
		self.add_body_params('DeviceTimeStamp', DeviceTimeStamp)

	def get_DeviceSn(self):
		return self.get_body_params().get('DeviceSn')

	def set_DeviceSn(self,DeviceSn):
		self.add_body_params('DeviceSn', DeviceSn)

	def get_DeviceId(self):
		return self.get_body_params().get('DeviceId')

	def set_DeviceId(self,DeviceId):
		self.add_body_params('DeviceId', DeviceId)

	def get_ServerId(self):
		return self.get_body_params().get('ServerId')

	def set_ServerId(self,ServerId):
		self.add_body_params('ServerId', ServerId)
